<?php
// API doc : https://coincheck.com/ja/documents/exchange/api#order-positions
// API url : https://coincheck.com/api/exchange/leverage/positions

// Please set ACCESS_KEY and SECRET_ACCESS_KEY
$ACCESS_KEY = "";
$SECRET_ACCESS_KEY = "";

// coincheck leverage positions api url
$url =  "https://coincheck.com/api/exchange/leverage/positions";

// proxy settings
$proxy      = ""; 
$proxy_port = ""; 

// check arguments
if (!check_arguments($argc, $argv)) {
    usage();
    exit(1);
}

if ($argc == 2) {
    $url = $url . "?status=" . $argv[1];
}

// create signature
$nonce = time();
$message = $nonce . $url;
$signature = hash_hmac("sha256", $message, $SECRET_ACCESS_KEY);

// header
$headers = array(
    "ACCESS-KEY: {$ACCESS_KEY}",
    "ACCESS-SIGNATURE: {$signature}",
    "ACCESS-NONCE: {$nonce}",
    );

$curl = curl_init();
if ($curl == FALSE) {
    fputs(STDERR, "[ERR] curl_init(): " . curl_error($curl) . PHP_EOL);
    die(1);
}
// set proxy server settings
if (!empty($proxy) && !empty($proxy_port)) {
    curl_setopt($curl, CURLOPT_HTTPPROXYTUNNEL, 1); 
    curl_setopt($curl, CURLOPT_PROXY, $proxy . ":" . $proxy_port);
    curl_setopt($curl, CURLOPT_PROXYPORT, $proxy_port);
}
curl_setopt($curl, CURLOPT_URL, $url);
curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);

$response = curl_exec($curl);
if ($response == FALSE) {
    fputs(STDERR, "[ERR] curl_exec(): " . curl_error($curl) . PHP_EOL);
    die(1);
}
curl_close($curl);

// json decode
$json_decode = json_decode($response, true);
if ($json_decode == NULL) {
    fputs(STDERR, "[ERR] json_decode(): " . json_last_error_msg() . PHP_EOL);
    die(1);
}

// output json_decode
print_r($json_decode);

exit(0);

//--------------------------------------------------
// functions
//--------------------------------------------------
function check_arguments($argc, $argv) {
    if (($argc != 1) and ($argc != 2)) { return FALSE; }
    if ($argc == 1) { return TRUE; }

    $opts = array("open", "closed");
    if (!in_array($argv[1], $opts)) { return FALSE; };
    return TRUE;
}

function usage() {
    print("Usage: php positions.php [open|closed]" . PHP_EOL .
          "    open   : show open positions." . PHP_EOL .
          "    closed : show closed postions." . PHP_EOL .
          "    nothing : show open and closed positions." . PHP_EOL
    );
}
